From: Jody McIntyre <scjody@sun.com>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, mathieu.desnoyers@polymtl.ca,
hpa@zytor.com, mingo@redhat.com, scjody@sun.com,
tglx@linutronix.de, mingo@elte.hu
Subject: [tip:tracing/docs] tracing: Documentation / sample code fixes for tracepoints
Date: Tue, 24 Mar 2009 21:33:30 GMT [thread overview]
Message-ID: <tip-0a5d649018b151cb9331c213a843ac4a3e7e44ab@git.kernel.org> (raw)
In-Reply-To: <20090324200027.GH8294@clouds>
Commit-ID: 0a5d649018b151cb9331c213a843ac4a3e7e44ab
Gitweb: http://git.kernel.org/tip/0a5d649018b151cb9331c213a843ac4a3e7e44ab
Author: Jody McIntyre <scjody@sun.com>
AuthorDate: Tue, 24 Mar 2009 16:00:28 -0400
Committer: Ingo Molnar <mingo@elte.hu>
CommitDate: Tue, 24 Mar 2009 22:32:12 +0100
tracing: Documentation / sample code fixes for tracepoints
Fix the tracepoint documentation to refer to "tracepoint-sample"
instead of "tracepoint-example" to match what actually exists;
fix the directory, and clarify how to compile.
Change every instance of "example" in the sample tracepoint code
to "sample" for consistency.
Signed-off-by: Jody McIntyre <scjody@sun.com>
Acked-by: Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
Cc: torvalds@linux-foundation.org
LKML-Reference: <20090324200027.GH8294@clouds>
Signed-off-by: Ingo Molnar <mingo@elte.hu>
---
Documentation/tracepoints.txt | 13 +++++++------
samples/tracepoints/tracepoint-sample.c | 24 ++++++++++++------------
2 files changed, 19 insertions(+), 18 deletions(-)
diff --git a/Documentation/tracepoints.txt b/Documentation/tracepoints.txt
index 4ff43c6..c0e1cee 100644
--- a/Documentation/tracepoints.txt
+++ b/Documentation/tracepoints.txt
@@ -103,13 +103,14 @@ used to export the defined tracepoints.
* Probe / tracepoint example
-See the example provided in samples/tracepoints/src
+See the example provided in samples/tracepoints
-Compile them with your kernel.
+Compile them with your kernel. They are built during 'make' (not
+'make modules') when CONFIG_SAMPLE_TRACEPOINTS=m.
Run, as root :
-modprobe tracepoint-example (insmod order is not important)
-modprobe tracepoint-probe-example
-cat /proc/tracepoint-example (returns an expected error)
-rmmod tracepoint-example tracepoint-probe-example
+modprobe tracepoint-sample (insmod order is not important)
+modprobe tracepoint-probe-sample
+cat /proc/tracepoint-sample (returns an expected error)
+rmmod tracepoint-sample tracepoint-probe-sample
dmesg
diff --git a/samples/tracepoints/tracepoint-sample.c b/samples/tracepoints/tracepoint-sample.c
index 68d5dc0..9cf80a1 100644
--- a/samples/tracepoints/tracepoint-sample.c
+++ b/samples/tracepoints/tracepoint-sample.c
@@ -1,6 +1,6 @@
/* tracepoint-sample.c
*
* Executes a tracepoint when /proc/tracepoint-example is opened.
*
* (C) Copyright 2007 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
*
@@ -16,7 +16,7 @@
DEFINE_TRACE(subsys_event);
DEFINE_TRACE(subsys_eventb);
-struct proc_dir_entry *pentry_example;
+struct proc_dir_entry *pentry_sample;
static int my_open(struct inode *inode, struct file *file)
{
@@ -32,25 +32,25 @@ static struct file_operations mark_ops = {
.open = my_open,
};
-static int __init example_init(void)
+static int __init sample_init(void)
{
- printk(KERN_ALERT "example init\n");
- pentry_example = proc_create("tracepoint-example", 0444, NULL,
+ printk(KERN_ALERT "sample init\n");
+ pentry_sample = proc_create("tracepoint-sample", 0444, NULL,
&mark_ops);
- if (!pentry_example)
+ if (!pentry_sample)
return -EPERM;
return 0;
}
-static void __exit example_exit(void)
+static void __exit sample_exit(void)
{
- printk(KERN_ALERT "example exit\n");
- remove_proc_entry("tracepoint-example", NULL);
+ printk(KERN_ALERT "sample exit\n");
+ remove_proc_entry("tracepoint-sample", NULL);
}
-module_init(example_init)
-module_exit(example_exit)
+module_init(sample_init)
+module_exit(sample_exit)
MODULE_LICENSE("GPL");
MODULE_AUTHOR("Mathieu Desnoyers");
-MODULE_DESCRIPTION("Tracepoint example");
+MODULE_DESCRIPTION("Tracepoint sample");
prev parent reply other threads:[~2009-03-24 21:34 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-03-24 20:00 [PATCH] Documentation / sample code fixes for tracepoints Jody McIntyre
2009-03-24 20:18 ` Mathieu Desnoyers
2009-03-24 21:32 ` Ingo Molnar
2009-03-25 12:25 ` Jody McIntyre
2009-03-24 21:33 ` Jody McIntyre [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-0a5d649018b151cb9331c213a843ac4a3e7e44ab@git.kernel.org \
--to=scjody@sun.com \
--cc=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mathieu.desnoyers@polymtl.ca \
--cc=mingo@elte.hu \
--cc=mingo@redhat.com \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1,6 +1,6 @@
/* tracepoint-sample.c
*
- * Executes a tracepoint when /proc/tracepoint-example is opened.
+ * Executes a tracepoint when /proc/tracepoint-sample is opened.
*
* (C) Copyright 2007 Mathieu Desnoyers <mathieu.desnoyers@polymtl.ca>
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox